@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from typing import Optional
 
 from ..utils.context_managed_generator import ContextManagedGenerator
 from .text_segment import TextSegment
@@ -16,11 +17,7 @@ class Text(ABC):
         ...
 
     @abstractmethod
-    def get_segments(self, include_text: bool = True) -> ContextManagedGenerator[TextSegment, None, None]:
-        ...
-
-    @abstractmethod
-    def get_segments_based_on(
-        self, text: "Text", include_text: bool = True
+    def get_segments(
+        self, include_text: bool = True, based_on: Optional["Text"] = None
     ) -> ContextManagedGenerator[TextSegment, None, None]:
         ...
