@@ -95,9 +95,11 @@ class UsfmTextBase(ScriptureText):
                     text += str(token)
             elif token.type == UsfmTokenType.CHARACTER:
                 assert token.marker is not None
-                if token.marker.marker in {"w", "jmp"}:
+                if token.marker.marker in _SPAN_MARKERS:
                     cur_span_marker = token.marker
-                elif token.marker.marker != "qac" and token.marker.text_type == UsfmTextType.OTHER:
+                elif token.marker.marker != "qac" and (
+                    token.marker.text_type == UsfmTextType.OTHER or token.marker.marker in _EMBED_MARKERS
+                ):
                     cur_embed_marker = token.marker
                     if not self._include_markers and token.marker.marker == "rq":
                         text = text.rstrip()
@@ -154,6 +156,10 @@ class UsfmTextBase(ScriptureText):
 
 _NONVERSE_PARA_STYLES = {"ms", "mr", "s", "sr", "r", "d", "sp", "rem", "restore", "cl", "cp"}
 
+_SPAN_MARKERS = {"w", "jmp"}
+
+_EMBED_MARKERS = {"fig", "va", "vp", "pro", "rq", "fm"}
+
 
 def _is_numbered_style(style_prefix: str, style: str) -> bool:
     return style.startswith(style_prefix) and is_integer(style[len(style_prefix) :])
