@@ -1,7 +1,7 @@
 from abc import abstractmethod
 from typing import Generator, Optional
 
-from ..scripture.verse_ref import VerseRef, Versification
+from ..scripture.verse_ref import Versification
 from ..tokenization.tokenizer import Tokenizer
 from .scripture_text import ScriptureText
 from .stream_container import StreamContainer
@@ -20,11 +20,9 @@ class UsxTextBase(ScriptureText):
     def _create_stream_container(self) -> StreamContainer:
         ...
 
-    def _get_segments(self, include_text: bool) -> Generator[TextSegment, None, None]:
+    def _get_segments_in_doc_order(self, include_text: bool) -> Generator[TextSegment, None, None]:
         with self._create_stream_container() as stream_container, stream_container.open_stream() as stream:
-            prev_verse_ref = VerseRef()
             for verse in self._parser.parse(stream):
-                for seg in self._create_text_segments(
-                    include_text, prev_verse_ref, verse.chapter, verse.verse, verse.text, verse.is_sentence_start
-                ):
-                    yield seg
+                yield from self._create_text_segments(
+                    include_text, verse.chapter, verse.verse, verse.text, verse.is_sentence_start
+                )
